@@ -127,7 +127,9 @@ class WherePred(WhereBoolean):
 
 class WhereQuery(WherePred):
     def __init__(self, name, value=None):
-        super(WhereQuery, self).__init__(_desugar(name if value is None else (name, value)))
+        super(WhereQuery, self).__init__(
+            _desugar(name if value is None else (name, value))
+        )
 
 
 make_child_query = WhereQuery
@@ -136,8 +138,8 @@ q = WhereQuery
 
 def _desugar(query):
     """
-    returns a function that accepts a dict and returns
-    all name value pairs from it that match the query.
+    returns a function that accepts a dict and returns a dict of all name
+    value pairs from it that match the query.
     """
     if isinstance(query, tuple):
         name, value = query
@@ -148,32 +150,35 @@ def _desugar(query):
             value = pred(value)
 
         if isinstance(name, Boolean) and isinstance(value, Boolean):
+
             def inner(node):
                 res = {}
                 for k, v in node.items():
                     if name.test(k) and value.test(v):
                         res[k] = v
                 return Dict(res, parent=node)
-            return inner
 
         elif isinstance(name, Boolean):
+
             def inner(node):
                 res = {}
                 for k, v in node.items():
                     if name.test(k) and v == value:
                         res[k] = v
                 return Dict(res, parent=node)
-            return inner
 
         elif isinstance(value, Boolean):
             if name is ANY:
+
                 def inner(node):
                     res = {}
                     for k, v in node.items():
                         if value.test(v):
                             res[k] = v
                     return Dict(res, parent=node)
+
             else:
+
                 def inner(node):
                     try:
                         v = node[name]
@@ -182,9 +187,9 @@ def _desugar(query):
                         return Dict({}, parent=node)
                     except:
                         return Dict({}, parent=node)
-            return inner
 
         else:
+
             def inner(node):
                 try:
                     v = node[name]
@@ -193,21 +198,23 @@ def _desugar(query):
                     return Dict({}, parent=node)
                 except:
                     return Dict({}, parent=node)
-            return inner
 
     elif query is ANY:
-        return lambda node: node
+
+        def inner(node):
+            return node
 
     elif isinstance(query, Boolean):
+
         def inner(node):
             res = {}
             for k, v in node.items():
                 if query.test(k):
                     res[k] = v
             return Dict(res, parent=node)
-        return inner
 
     elif callable(query):
+
         def inner(node):
             res = {}
             for k, v in node.items():
@@ -217,15 +224,16 @@ def _desugar(query):
                 except:
                     pass
             return Dict(res, parent=node)
-        return inner
 
     else:
+
         def inner(node):
             try:
                 return Dict({query: node[query]}, parent=node)
             except:
                 return Dict({}, parent=node)
-        return inner
+
+    return inner
 
 
 def _query(pred, value):
@@ -356,7 +364,7 @@ class _Queryable:
                 gp = p.parent
                 if isinstance(gp, list):
                     gp = gp.parent
-                if gp is seen:
+                if gp is seen and seen is not None:
                     res.append(p)
                     break
                 if gp is not None:
@@ -403,6 +411,7 @@ class _Queryable:
         elif isinstance(name, Boolean):
             qry = WhereQuery(name, value)
         elif callable(name):
+
             def inner(value):
                 if name(_Queryable(value)):
                     return value
@@ -423,6 +432,7 @@ class _Queryable:
 
     def to_df(self):
         import pandas
+
         return pandas.DataFrame(self.values)
 
     def most_common(self, n=None):
